@@ -1,9 +1,28 @@
 #[allow(warnings)]
 #[macro_use]
 pub mod macros {
+    /// return base_uri
+    /// ```ignore
+    /// use wasm_macro::*;
+    ///  onclick:move|_|{
+    ///            console_log!(document_base_uri!());
+    ///        }
+    /// ```
+    #[macro_export]
+    macro_rules! document_base_uri {
+        () => {{
+            let window = web_sys::window().expect("no global `window` exists");
+            let document = window.document().expect("should have a document on window");
+            let uri = document
+                .base_uri()
+                .expect("should have a base URI on window");
+            uri
+        }};
+    }
     /// location_assign!("/admin") navigate to /admin route
+    ///
     /// location_assign!("/search?q=rust") navigate to /search and with params
-    /// ```rust
+    /// ```ignore
     /// use wasm_macro::*;
     ///  onclick:move|_|{
     ///            location_assign!("/demo");// nevigate to /demo
@@ -16,7 +35,7 @@ pub mod macros {
             window.location().assign(&format!("{}", $to));
         }};
     }
-    /// location_herf!() get current location herf
+    ///  get current location herf
     /// ```ignore
     /// use wasm_macro::*;
     ///  onclick:move|_|{
@@ -32,7 +51,7 @@ pub mod macros {
             herf
         }};
     }
-    /// location_reload!() Reload the resource from the current URL
+    /// Reload the resource from the current URL
     /// ```ignore
     /// use wasm_macro::*;
     ///  onclick:move|_|{
@@ -47,7 +66,7 @@ pub mod macros {
         }};
     }
 
-    /// document_query_selector!() return first Element within the document that matches the specified selector, or group of selectors
+    ///return first Element within the document that matches the specified selector, or group of selectors
     /// ```ignore
     /// use wasm_macro::*;
     ///  onclick:move|_|{
@@ -71,7 +90,7 @@ pub mod macros {
             dom
         }};
     }
-    /// document_query_selector!() returns a static (not live) NodeList representing a list of the document's elements that match the specified group of selectors.
+    /// returns a static (not live) NodeList representing a list of the document's elements that match the specified group of selectors.
     /// ```ignore
     /// use wasm_macro::*;
     ///  onclick:move|_|{
@@ -94,8 +113,7 @@ pub mod macros {
             dom
         }};
     }
-    // document_create_element
-    /// document_create_element!() create Element
+    ///Create Element
     /// ```ignore
     /// use wasm_macro::*;
     ///  onclick:move|_|{
@@ -119,7 +137,7 @@ pub mod macros {
             val
         }};
     }
-    /// element_inner_html!() get inner_html value of String
+    ///  get inner_html value of String
     /// ```ignore
     /// use wasm_macro::*;
     ///  onclick:move|_|{
@@ -133,7 +151,7 @@ pub mod macros {
             element.inner_html()
         }};
     }
-    /// element_set_inner_html!() set inner_html to value
+    ///set inner_html to value
     /// ```ignore
     /// use wasm_macro::*;
     ///  onclick:move|_|{
@@ -147,7 +165,7 @@ pub mod macros {
             element.set_inner_html($val);
         }};
     }
-    /// element_set_inner_html!() set inner_html to value
+    ///  log value to browser console
     /// ```ignore
     /// use wasm_macro::*;
     ///  onclick:move|_|{
